@@ -1,8 +1,8 @@
 /*
- *  Copyright (C) 2002 Ricardo Fernádez Pascual
- *  Copyright (C) 2005 Crispin Flowerday
- *  Copyright (C) 2005 Christian Persch
- *  Copyright (C) 2005 Samuel Abels
+ *  Copyright © 2002 Ricardo Fernádez Pascual
+ *  Copyright © 2005 Crispin Flowerday
+ *  Copyright © 2005 Christian Persch
+ *  Copyright © 2005 Samuel Abels
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-push-scroller.c,v 1.4 2006/04/10 20:29:58 chpe Exp $
+ *  $Id: ephy-push-scroller.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 /* this file is based on work of Daniel Erat for galeon 1 */
@@ -368,7 +368,7 @@ ephy_push_scroller_get_type (void)
 GType
 ephy_push_scroller_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyPushScrollerClass),
 		NULL, /* base_init */
